"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.staff_permission_group import (
    StaffPermissionGroup,
)


class UpdateStaffPermissionsResponse(object):
    """Implementation of the 'UpdateStaffPermissionsResponse' model.

    Attributes:
        user_group (StaffPermissionGroup): The model property of type
            StaffPermissionGroup.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "user_group": "UserGroup",
    }

    _optionals = [
        "user_group",
    ]

    def __init__(
        self,
        user_group=APIHelper.SKIP):
        """Initialize a UpdateStaffPermissionsResponse instance."""
        # Initialize members of the class
        if user_group is not APIHelper.SKIP:
            self.user_group = user_group

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        user_group =\
            StaffPermissionGroup.from_dictionary(
                dictionary.get("UserGroup"))\
                if "UserGroup" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(user_group)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _user_group=(
            self.user_group
            if hasattr(self, "user_group")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"user_group={_user_group!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _user_group=(
            self.user_group
            if hasattr(self, "user_group")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"user_group={_user_group!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.class_schedule import (
    ClassSchedule,
)
from mindbodypublicapi.models.client import (
    Client,
)


class WaitlistEntry(object):
    """Implementation of the 'WaitlistEntry' model.

    Attributes:
        class_date (datetime): The date of the class or enrollment.
        class_id (int): The ID of the class or enrollment.
        class_schedule (ClassSchedule): Represents a single class instance. The class
            meets at the start time, goes until the end time.
        client (Client): The Client.
        enrollment_date_forward (datetime): If the waiting list entry was created for
            an enrollment, this is the date on or after which the client can be added
            to the enrollment from the waitlist.
        id (int): The ID of the waiting list entry.
        request_date_time (datetime): The date and time that the request to be on the
            waiting list was made.
        visit_ref_no (int): The ID of the visit that is associated with the waiting
            list entry.
        web (bool): If `true`, the entry on the waiting list was requested online.<br
            />  If `false`, the entry on the waiting list was requested off-line, for
            example in person or by phone.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_date": "ClassDate",
        "class_id": "ClassId",
        "class_schedule": "ClassSchedule",
        "client": "Client",
        "enrollment_date_forward": "EnrollmentDateForward",
        "id": "Id",
        "request_date_time": "RequestDateTime",
        "visit_ref_no": "VisitRefNo",
        "web": "Web",
    }

    _optionals = [
        "class_date",
        "class_id",
        "class_schedule",
        "client",
        "enrollment_date_forward",
        "id",
        "request_date_time",
        "visit_ref_no",
        "web",
    ]

    def __init__(
        self,
        class_date=APIHelper.SKIP,
        class_id=APIHelper.SKIP,
        class_schedule=APIHelper.SKIP,
        client=APIHelper.SKIP,
        enrollment_date_forward=APIHelper.SKIP,
        id=APIHelper.SKIP,
        request_date_time=APIHelper.SKIP,
        visit_ref_no=APIHelper.SKIP,
        web=APIHelper.SKIP):
        """Initialize a WaitlistEntry instance."""
        # Initialize members of the class
        if class_date is not APIHelper.SKIP:
            self.class_date =\
                 APIHelper.apply_datetime_converter(
                class_date, APIHelper.RFC3339DateTime)\
                 if class_date else None
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        if class_schedule is not APIHelper.SKIP:
            self.class_schedule = class_schedule
        if client is not APIHelper.SKIP:
            self.client = client
        if enrollment_date_forward is not APIHelper.SKIP:
            self.enrollment_date_forward =\
                 APIHelper.apply_datetime_converter(
                enrollment_date_forward, APIHelper.RFC3339DateTime)\
                 if enrollment_date_forward else None
        if id is not APIHelper.SKIP:
            self.id = id
        if request_date_time is not APIHelper.SKIP:
            self.request_date_time =\
                 APIHelper.apply_datetime_converter(
                request_date_time, APIHelper.RFC3339DateTime)\
                 if request_date_time else None
        if visit_ref_no is not APIHelper.SKIP:
            self.visit_ref_no = visit_ref_no
        if web is not APIHelper.SKIP:
            self.web = web

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ClassDate")).datetime\
            if dictionary.get("ClassDate") else APIHelper.SKIP
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else APIHelper.SKIP
        class_schedule =\
            ClassSchedule.from_dictionary(
                dictionary.get("ClassSchedule"))\
                if "ClassSchedule" in dictionary.keys()\
                else APIHelper.SKIP
        client =\
            Client.from_dictionary(
                dictionary.get("Client"))\
                if "Client" in dictionary.keys()\
                else APIHelper.SKIP
        enrollment_date_forward = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EnrollmentDateForward")).datetime\
            if dictionary.get("EnrollmentDateForward") else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        request_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("RequestDateTime")).datetime\
            if dictionary.get("RequestDateTime") else APIHelper.SKIP
        visit_ref_no =\
            dictionary.get("VisitRefNo")\
            if dictionary.get("VisitRefNo")\
                else APIHelper.SKIP
        web =\
            dictionary.get("Web")\
            if "Web" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_date,
                   class_id,
                   class_schedule,
                   client,
                   enrollment_date_forward,
                   id,
                   request_date_time,
                   visit_ref_no,
                   web)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_date=(
            self.class_date
            if hasattr(self, "class_date")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_schedule=(
            self.class_schedule
            if hasattr(self, "class_schedule")
            else None
        )
        _client=(
            self.client
            if hasattr(self, "client")
            else None
        )
        _enrollment_date_forward=(
            self.enrollment_date_forward
            if hasattr(self, "enrollment_date_forward")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _request_date_time=(
            self.request_date_time
            if hasattr(self, "request_date_time")
            else None
        )
        _visit_ref_no=(
            self.visit_ref_no
            if hasattr(self, "visit_ref_no")
            else None
        )
        _web=(
            self.web
            if hasattr(self, "web")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_date={_class_date!r}, "
            f"class_id={_class_id!r}, "
            f"class_schedule={_class_schedule!r}, "
            f"client={_client!r}, "
            f"enrollment_date_forward={_enrollment_date_forward!r}, "
            f"id={_id!r}, "
            f"request_date_time={_request_date_time!r}, "
            f"visit_ref_no={_visit_ref_no!r}, "
            f"web={_web!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_date=(
            self.class_date
            if hasattr(self, "class_date")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_schedule=(
            self.class_schedule
            if hasattr(self, "class_schedule")
            else None
        )
        _client=(
            self.client
            if hasattr(self, "client")
            else None
        )
        _enrollment_date_forward=(
            self.enrollment_date_forward
            if hasattr(self, "enrollment_date_forward")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _request_date_time=(
            self.request_date_time
            if hasattr(self, "request_date_time")
            else None
        )
        _visit_ref_no=(
            self.visit_ref_no
            if hasattr(self, "visit_ref_no")
            else None
        )
        _web=(
            self.web
            if hasattr(self, "web")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_date={_class_date!s}, "
            f"class_id={_class_id!s}, "
            f"class_schedule={_class_schedule!s}, "
            f"client={_client!s}, "
            f"enrollment_date_forward={_enrollment_date_forward!s}, "
            f"id={_id!s}, "
            f"request_date_time={_request_date_time!s}, "
            f"visit_ref_no={_visit_ref_no!s}, "
            f"web={_web!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class Liability(object):
    """Implementation of the 'Liability' model.

    Attributes:
        agreement_date (datetime): The date and time at which the client agreed to
            the liability waiver for the business.
        is_released (bool): The client’s liability release status.<br />  When
            `true`, indicates that the client has agreed to the liability release for
            the business.<br />  When `false`, indicates that the client has not
            agreed to the liability release for the business.
        released_by (int): An ID indicating who released liability for the client. If
            the client agreed to the liability waiver by signing into an account
            online, this value is `null`. If a staff member marked the waiver as
            signed on behalf of the client, it is the staff member’s ID. `0`
            indicates that the business owner marked the liability waiver as signed
            on behalf of the client.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "agreement_date": "AgreementDate",
        "is_released": "IsReleased",
        "released_by": "ReleasedBy",
    }

    _optionals = [
        "agreement_date",
        "is_released",
        "released_by",
    ]

    def __init__(
        self,
        agreement_date=APIHelper.SKIP,
        is_released=APIHelper.SKIP,
        released_by=APIHelper.SKIP):
        """Initialize a Liability instance."""
        # Initialize members of the class
        if agreement_date is not APIHelper.SKIP:
            self.agreement_date =\
                 APIHelper.apply_datetime_converter(
                agreement_date, APIHelper.RFC3339DateTime)\
                 if agreement_date else None
        if is_released is not APIHelper.SKIP:
            self.is_released = is_released
        if released_by is not APIHelper.SKIP:
            self.released_by = released_by

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        agreement_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("AgreementDate")).datetime\
            if dictionary.get("AgreementDate") else APIHelper.SKIP
        is_released =\
            dictionary.get("IsReleased")\
            if "IsReleased" in dictionary.keys()\
                else APIHelper.SKIP
        released_by =\
            dictionary.get("ReleasedBy")\
            if dictionary.get("ReleasedBy")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(agreement_date,
                   is_released,
                   released_by)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _agreement_date=(
            self.agreement_date
            if hasattr(self, "agreement_date")
            else None
        )
        _is_released=(
            self.is_released
            if hasattr(self, "is_released")
            else None
        )
        _released_by=(
            self.released_by
            if hasattr(self, "released_by")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"agreement_date={_agreement_date!r}, "
            f"is_released={_is_released!r}, "
            f"released_by={_released_by!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _agreement_date=(
            self.agreement_date
            if hasattr(self, "agreement_date")
            else None
        )
        _is_released=(
            self.is_released
            if hasattr(self, "is_released")
            else None
        )
        _released_by=(
            self.released_by
            if hasattr(self, "released_by")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"agreement_date={_agreement_date!s}, "
            f"is_released={_is_released!s}, "
            f"released_by={_released_by!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetLiabilityWaiverResponse(object):
    """Implementation of the 'GetLiabilityWaiverResponse' model.

    Attributes:
        liability_waiver (str): Contains Liability Waiver text for a site

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "liability_waiver": "LiabilityWaiver",
    }

    _optionals = [
        "liability_waiver",
    ]

    def __init__(
        self,
        liability_waiver=APIHelper.SKIP):
        """Initialize a GetLiabilityWaiverResponse instance."""
        # Initialize members of the class
        if liability_waiver is not APIHelper.SKIP:
            self.liability_waiver = liability_waiver

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        liability_waiver =\
            dictionary.get("LiabilityWaiver")\
            if dictionary.get("LiabilityWaiver")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(liability_waiver)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _liability_waiver=(
            self.liability_waiver
            if hasattr(self, "liability_waiver")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"liability_waiver={_liability_waiver!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _liability_waiver=(
            self.liability_waiver
            if hasattr(self, "liability_waiver")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"liability_waiver={_liability_waiver!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class CompleteCheckoutShoppingCartUsingAlternativePaymentsRequest(object):
    """Implementation of the
    'CompleteCheckoutShoppingCartUsingAlternativePaymentsRequest' model.

    The API Request model for Complete Checkout Shopping Cart API.

    Attributes:
        access_token (str): The Access Token generated during Pre-Payment step.
        client_id (str): The RSSID of the client making the purchase. A cart can be
            validated without a client ID, but a client ID must be specified to
            complete a sale.
        test (bool): When `true`, indicates that the contents of the cart are
            validated, but the transaction does not take place. You should use this
            parameter during testing and when checking the calculated totals of the
            items in the cart.<br />  When `false`, the transaction takes place and
            the database is affected.<br />  Default: **false**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "access_token": "AccessToken",
        "client_id": "ClientId",
        "test": "Test",
    }

    _optionals = [
        "test",
    ]

    def __init__(
        self,
        access_token=None,
        client_id=None,
        test=APIHelper.SKIP):
        """Initialize a
        CompleteCheckoutShoppingCartUsingAlternativePaymentsRequest instance.
        """
        # Initialize members of the class
        self.access_token = access_token
        self.client_id = client_id
        if test is not APIHelper.SKIP:
            self.test = test

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        access_token =\
            dictionary.get("AccessToken")\
            if dictionary.get("AccessToken")\
                else None
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(access_token,
                   client_id,
                   test)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _access_token=self.access_token
        _client_id=self.client_id
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"access_token={_access_token!r}, "
            f"client_id={_client_id!r}, "
            f"test={_test!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _access_token=self.access_token
        _client_id=self.client_id
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"access_token={_access_token!s}, "
            f"client_id={_client_id!s}, "
            f"test={_test!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetCrossRegionalClientAssociationsRequest(object):
    """Implementation of the 'GetCrossRegionalClientAssociationsRequest' model.

    Attributes:
        unique_client_id (int): Looks up the cross regional associations by the
            unique client’s ID.  Note: you need to provide the 'UniqueClientId' OR
            the 'ClientId' OR the 'Email'.   'UniqueClientId' takes precedence when
            provided. If not, but both 'ClientId' and 'Email' are provided,
            'ClientId' is used by default.
        client_id (str): Looks up the cross regional associations by the client’s ID.
        email (str): Looks up the cross regional associations by the client’s email
            address.
        first_name (str): First name (used for email queries)
        last_name (str): Last name (used for email queries)
        v_2 (bool): Use newer method
        exclude_inactive_sites (bool): Used to exclude inactive and deleted sites
            from the results.  When this flag is set to `true`, client profiles
            associated with inactive and deleted sites are not getting returned.
            When this flag is set to `false`,client profiles associated with inactive
            and deleted sites are getting returned.  Default: **true**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "unique_client_id": "UniqueClientId",
        "client_id": "ClientId",
        "email": "Email",
        "first_name": "FirstName",
        "last_name": "LastName",
        "v_2": "V2",
        "exclude_inactive_sites": "ExcludeInactiveSites",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "unique_client_id",
        "client_id",
        "email",
        "first_name",
        "last_name",
        "v_2",
        "exclude_inactive_sites",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        unique_client_id=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        email=APIHelper.SKIP,
        first_name=APIHelper.SKIP,
        last_name=APIHelper.SKIP,
        v_2=APIHelper.SKIP,
        exclude_inactive_sites=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetCrossRegionalClientAssociationsRequest instance."""
        # Initialize members of the class
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if email is not APIHelper.SKIP:
            self.email = email
        if first_name is not APIHelper.SKIP:
            self.first_name = first_name
        if last_name is not APIHelper.SKIP:
            self.last_name = last_name
        if v_2 is not APIHelper.SKIP:
            self.v_2 = v_2
        if exclude_inactive_sites is not APIHelper.SKIP:
            self.exclude_inactive_sites = exclude_inactive_sites
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        email =\
            dictionary.get("Email")\
            if dictionary.get("Email")\
                else APIHelper.SKIP
        first_name =\
            dictionary.get("FirstName")\
            if dictionary.get("FirstName")\
                else APIHelper.SKIP
        last_name =\
            dictionary.get("LastName")\
            if dictionary.get("LastName")\
                else APIHelper.SKIP
        v_2 =\
            dictionary.get("V2")\
            if "V2" in dictionary.keys()\
                else APIHelper.SKIP
        exclude_inactive_sites =\
            dictionary.get("ExcludeInactiveSites")\
            if "ExcludeInactiveSites" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(unique_client_id,
                   client_id,
                   email,
                   first_name,
                   last_name,
                   v_2,
                   exclude_inactive_sites,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _v_2=(
            self.v_2
            if hasattr(self, "v_2")
            else None
        )
        _exclude_inactive_sites=(
            self.exclude_inactive_sites
            if hasattr(self, "exclude_inactive_sites")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"unique_client_id={_unique_client_id!r}, "
            f"client_id={_client_id!r}, "
            f"email={_email!r}, "
            f"first_name={_first_name!r}, "
            f"last_name={_last_name!r}, "
            f"v_2={_v_2!r}, "
            f"exclude_inactive_sites={_exclude_inactive_sites!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _v_2=(
            self.v_2
            if hasattr(self, "v_2")
            else None
        )
        _exclude_inactive_sites=(
            self.exclude_inactive_sites
            if hasattr(self, "exclude_inactive_sites")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"unique_client_id={_unique_client_id!s}, "
            f"client_id={_client_id!s}, "
            f"email={_email!s}, "
            f"first_name={_first_name!s}, "
            f"last_name={_last_name!s}, "
            f"v_2={_v_2!s}, "
            f"exclude_inactive_sites={_exclude_inactive_sites!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class SubstituteClassTeacherRequest(object):
    """Implementation of the 'SubstituteClassTeacherRequest' model.

    Attributes:
        class_id (int): The ID of the class to which a substitute teacher needs to be
            assigned.
        staff_id (int): The staff ID of the teacher to substitute.
        override_conflicts (bool): When `true`, overrides any conflicts in the
            schedule.
        send_client_email (bool): When `true`, sends the client an automatic email
            about the substitution, if the client has opted to receive email.
        send_original_teacher_email (bool): When `true`, sends the originally
            scheduled teacher an automatic email about the substitution.
        send_substitute_teacher_email (bool): When `true`, sends the substituted
            teacher an automatic email about the substitution.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_id": "ClassId",
        "staff_id": "StaffId",
        "override_conflicts": "OverrideConflicts",
        "send_client_email": "SendClientEmail",
        "send_original_teacher_email": "SendOriginalTeacherEmail",
        "send_substitute_teacher_email": "SendSubstituteTeacherEmail",
    }

    _optionals = [
        "override_conflicts",
        "send_client_email",
        "send_original_teacher_email",
        "send_substitute_teacher_email",
    ]

    def __init__(
        self,
        class_id=None,
        staff_id=None,
        override_conflicts=APIHelper.SKIP,
        send_client_email=APIHelper.SKIP,
        send_original_teacher_email=APIHelper.SKIP,
        send_substitute_teacher_email=APIHelper.SKIP):
        """Initialize a SubstituteClassTeacherRequest instance."""
        # Initialize members of the class
        self.class_id = class_id
        self.staff_id = staff_id
        if override_conflicts is not APIHelper.SKIP:
            self.override_conflicts = override_conflicts
        if send_client_email is not APIHelper.SKIP:
            self.send_client_email = send_client_email
        if send_original_teacher_email is not APIHelper.SKIP:
            self.send_original_teacher_email = send_original_teacher_email
        if send_substitute_teacher_email is not APIHelper.SKIP:
            self.send_substitute_teacher_email = send_substitute_teacher_email

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else None
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else None
        override_conflicts =\
            dictionary.get("OverrideConflicts")\
            if "OverrideConflicts" in dictionary.keys()\
                else APIHelper.SKIP
        send_client_email =\
            dictionary.get("SendClientEmail")\
            if "SendClientEmail" in dictionary.keys()\
                else APIHelper.SKIP
        send_original_teacher_email =\
            dictionary.get("SendOriginalTeacherEmail")\
            if "SendOriginalTeacherEmail" in dictionary.keys()\
                else APIHelper.SKIP
        send_substitute_teacher_email =\
            dictionary.get("SendSubstituteTeacherEmail")\
            if "SendSubstituteTeacherEmail" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_id,
                   staff_id,
                   override_conflicts,
                   send_client_email,
                   send_original_teacher_email,
                   send_substitute_teacher_email)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_id=self.class_id
        _staff_id=self.staff_id
        _override_conflicts=(
            self.override_conflicts
            if hasattr(self, "override_conflicts")
            else None
        )
        _send_client_email=(
            self.send_client_email
            if hasattr(self, "send_client_email")
            else None
        )
        _send_original_teacher_email=(
            self.send_original_teacher_email
            if hasattr(self, "send_original_teacher_email")
            else None
        )
        _send_substitute_teacher_email=(
            self.send_substitute_teacher_email
            if hasattr(self, "send_substitute_teacher_email")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_id={_class_id!r}, "
            f"staff_id={_staff_id!r}, "
            f"override_conflicts={_override_conflicts!r}, "
            f"send_client_email={_send_client_email!r}, "
            f"send_original_teacher_email={_send_original_teacher_email!r}, "
            f"send_substitute_teacher_email={_send_substitute_teacher_email!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_id=self.class_id
        _staff_id=self.staff_id
        _override_conflicts=(
            self.override_conflicts
            if hasattr(self, "override_conflicts")
            else None
        )
        _send_client_email=(
            self.send_client_email
            if hasattr(self, "send_client_email")
            else None
        )
        _send_original_teacher_email=(
            self.send_original_teacher_email
            if hasattr(self, "send_original_teacher_email")
            else None
        )
        _send_substitute_teacher_email=(
            self.send_substitute_teacher_email
            if hasattr(self, "send_substitute_teacher_email")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_id={_class_id!s}, "
            f"staff_id={_staff_id!s}, "
            f"override_conflicts={_override_conflicts!s}, "
            f"send_client_email={_send_client_email!s}, "
            f"send_original_teacher_email={_send_original_teacher_email!s}, "
            f"send_substitute_teacher_email={_send_substitute_teacher_email!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UpdateSiteClientIndexResponse(object):
    """Implementation of the 'UpdateSiteClientIndexResponse' model.

    Attributes:
        client_index_id (int): ID of the client index.
        client_index_name (str): The name of the client index.
        active (bool): Indicates if Client Index is Active
        show_on_new_client (bool): Indicates if Client Index is shown on a new client
            profile
        show_on_enrollment_roster (bool): Indicates if Client Index is shown on
            Enrollement Roster
        edit_on_enrollment_roster (bool): Indicates if Client Index can be edited on
            Enrollement Roster
        sort_order (int): Indicates sort order
        show_in_consumer_mode (bool): Indicates if Client Index is shown in consumer
            mode.
        required_consumer_mode (bool): Indicates if the index is required when
            creating profiles in consumer mode.
        required_biz_mode (bool): Indicates if the index is required when creating
            profiles in business mode.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_index_id": "ClientIndexID",
        "client_index_name": "ClientIndexName",
        "active": "Active",
        "show_on_new_client": "ShowOnNewClient",
        "show_on_enrollment_roster": "ShowOnEnrollmentRoster",
        "edit_on_enrollment_roster": "EditOnEnrollmentRoster",
        "sort_order": "SortOrder",
        "show_in_consumer_mode": "ShowInConsumerMode",
        "required_consumer_mode": "RequiredConsumerMode",
        "required_biz_mode": "RequiredBizMode",
    }

    _optionals = [
        "client_index_id",
        "client_index_name",
        "active",
        "show_on_new_client",
        "show_on_enrollment_roster",
        "edit_on_enrollment_roster",
        "sort_order",
        "show_in_consumer_mode",
        "required_consumer_mode",
        "required_biz_mode",
    ]

    def __init__(
        self,
        client_index_id=APIHelper.SKIP,
        client_index_name=APIHelper.SKIP,
        active=APIHelper.SKIP,
        show_on_new_client=APIHelper.SKIP,
        show_on_enrollment_roster=APIHelper.SKIP,
        edit_on_enrollment_roster=APIHelper.SKIP,
        sort_order=APIHelper.SKIP,
        show_in_consumer_mode=APIHelper.SKIP,
        required_consumer_mode=APIHelper.SKIP,
        required_biz_mode=APIHelper.SKIP):
        """Initialize a UpdateSiteClientIndexResponse instance."""
        # Initialize members of the class
        if client_index_id is not APIHelper.SKIP:
            self.client_index_id = client_index_id
        if client_index_name is not APIHelper.SKIP:
            self.client_index_name = client_index_name
        if active is not APIHelper.SKIP:
            self.active = active
        if show_on_new_client is not APIHelper.SKIP:
            self.show_on_new_client = show_on_new_client
        if show_on_enrollment_roster is not APIHelper.SKIP:
            self.show_on_enrollment_roster = show_on_enrollment_roster
        if edit_on_enrollment_roster is not APIHelper.SKIP:
            self.edit_on_enrollment_roster = edit_on_enrollment_roster
        if sort_order is not APIHelper.SKIP:
            self.sort_order = sort_order
        if show_in_consumer_mode is not APIHelper.SKIP:
            self.show_in_consumer_mode = show_in_consumer_mode
        if required_consumer_mode is not APIHelper.SKIP:
            self.required_consumer_mode = required_consumer_mode
        if required_biz_mode is not APIHelper.SKIP:
            self.required_biz_mode = required_biz_mode

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_index_id =\
            dictionary.get("ClientIndexID")\
            if dictionary.get("ClientIndexID")\
                else APIHelper.SKIP
        client_index_name =\
            dictionary.get("ClientIndexName")\
            if dictionary.get("ClientIndexName")\
                else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        show_on_new_client =\
            dictionary.get("ShowOnNewClient")\
            if "ShowOnNewClient" in dictionary.keys()\
                else APIHelper.SKIP
        show_on_enrollment_roster =\
            dictionary.get("ShowOnEnrollmentRoster")\
            if "ShowOnEnrollmentRoster" in dictionary.keys()\
                else APIHelper.SKIP
        edit_on_enrollment_roster =\
            dictionary.get("EditOnEnrollmentRoster")\
            if "EditOnEnrollmentRoster" in dictionary.keys()\
                else APIHelper.SKIP
        sort_order =\
            dictionary.get("SortOrder")\
            if dictionary.get("SortOrder")\
                else APIHelper.SKIP
        show_in_consumer_mode =\
            dictionary.get("ShowInConsumerMode")\
            if "ShowInConsumerMode" in dictionary.keys()\
                else APIHelper.SKIP
        required_consumer_mode =\
            dictionary.get("RequiredConsumerMode")\
            if "RequiredConsumerMode" in dictionary.keys()\
                else APIHelper.SKIP
        required_biz_mode =\
            dictionary.get("RequiredBizMode")\
            if "RequiredBizMode" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_index_id,
                   client_index_name,
                   active,
                   show_on_new_client,
                   show_on_enrollment_roster,
                   edit_on_enrollment_roster,
                   sort_order,
                   show_in_consumer_mode,
                   required_consumer_mode,
                   required_biz_mode)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_index_id=(
            self.client_index_id
            if hasattr(self, "client_index_id")
            else None
        )
        _client_index_name=(
            self.client_index_name
            if hasattr(self, "client_index_name")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _show_on_new_client=(
            self.show_on_new_client
            if hasattr(self, "show_on_new_client")
            else None
        )
        _show_on_enrollment_roster=(
            self.show_on_enrollment_roster
            if hasattr(self, "show_on_enrollment_roster")
            else None
        )
        _edit_on_enrollment_roster=(
            self.edit_on_enrollment_roster
            if hasattr(self, "edit_on_enrollment_roster")
            else None
        )
        _sort_order=(
            self.sort_order
            if hasattr(self, "sort_order")
            else None
        )
        _show_in_consumer_mode=(
            self.show_in_consumer_mode
            if hasattr(self, "show_in_consumer_mode")
            else None
        )
        _required_consumer_mode=(
            self.required_consumer_mode
            if hasattr(self, "required_consumer_mode")
            else None
        )
        _required_biz_mode=(
            self.required_biz_mode
            if hasattr(self, "required_biz_mode")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_index_id={_client_index_id!r}, "
            f"client_index_name={_client_index_name!r}, "
            f"active={_active!r}, "
            f"show_on_new_client={_show_on_new_client!r}, "
            f"show_on_enrollment_roster={_show_on_enrollment_roster!r}, "
            f"edit_on_enrollment_roster={_edit_on_enrollment_roster!r}, "
            f"sort_order={_sort_order!r}, "
            f"show_in_consumer_mode={_show_in_consumer_mode!r}, "
            f"required_consumer_mode={_required_consumer_mode!r}, "
            f"required_biz_mode={_required_biz_mode!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_index_id=(
            self.client_index_id
            if hasattr(self, "client_index_id")
            else None
        )
        _client_index_name=(
            self.client_index_name
            if hasattr(self, "client_index_name")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _show_on_new_client=(
            self.show_on_new_client
            if hasattr(self, "show_on_new_client")
            else None
        )
        _show_on_enrollment_roster=(
            self.show_on_enrollment_roster
            if hasattr(self, "show_on_enrollment_roster")
            else None
        )
        _edit_on_enrollment_roster=(
            self.edit_on_enrollment_roster
            if hasattr(self, "edit_on_enrollment_roster")
            else None
        )
        _sort_order=(
            self.sort_order
            if hasattr(self, "sort_order")
            else None
        )
        _show_in_consumer_mode=(
            self.show_in_consumer_mode
            if hasattr(self, "show_in_consumer_mode")
            else None
        )
        _required_consumer_mode=(
            self.required_consumer_mode
            if hasattr(self, "required_consumer_mode")
            else None
        )
        _required_biz_mode=(
            self.required_biz_mode
            if hasattr(self, "required_biz_mode")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_index_id={_client_index_id!s}, "
            f"client_index_name={_client_index_name!s}, "
            f"active={_active!s}, "
            f"show_on_new_client={_show_on_new_client!s}, "
            f"show_on_enrollment_roster={_show_on_enrollment_roster!s}, "
            f"edit_on_enrollment_roster={_edit_on_enrollment_roster!s}, "
            f"sort_order={_sort_order!s}, "
            f"show_in_consumer_mode={_show_in_consumer_mode!s}, "
            f"required_consumer_mode={_required_consumer_mode!s}, "
            f"required_biz_mode={_required_biz_mode!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddClassEnrollmentScheduleRequest(object):
    """Implementation of the 'AddClassEnrollmentScheduleRequest' model.

    Attributes:
        class_description_id (int): The Id of the class/enrollment description. This
            can be found in GetClassDescriptions.
        location_id (int): The Location Id of the enrollment schedule.
        start_date (datetime): The start date of the enrollment schedule.
        end_date (datetime): The end date of the enrollment schedule.
        start_time (datetime): Enrollment start time (use null or omit for TBD).
        end_time (datetime): Enrollment end time (ignored if StartTime is null or
            omitted).
        day_sunday (bool): If the enrollment occurs on Sunday(s).
        day_monday (bool): If the enrollment occurs on Monday(s).
        day_tuesday (bool): If the enrollment occurs on Tuesday(s).
        day_wednesday (bool): If the enrollment occurs on Wednesday(s).
        day_thursday (bool): If the enrollment occurs on Thursday(s).
        day_friday (bool): If the enrollment occurs on Friday(s).
        day_saturday (bool): If the enrollment occurs on Saturday(s).
        staff_id (int): The staff member teaching the enrollment.
        staff_pay_rate (int): The staff pay rate. Must be between 1-21.
        resource_id (int): The room where the enrollment is taking place.
        max_capacity (int): How many people can attend.
        web_capacity (int): How many people can signup online.  Default: **0**
        waitlist_capacity (int): How many people can waitlist.  Default:**0**
        booking_status (str): One of: PaymentRequired, BookAndPayLater, Free
        allow_open_enrollment (bool): Allow clients to choose which sessions they’d
            like to sign up for.  Default: **false**
        allow_date_forward_enrollment (bool): Allow booking after the enrollment has
            started.  Default: **false**
        pricing_options_product_ids (List[int]): Pricing Options for this schedule
        show_to_public (bool): Allow clients to see this schedule  Default: **true**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_description_id": "ClassDescriptionId",
        "location_id": "LocationId",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "start_time": "StartTime",
        "end_time": "EndTime",
        "day_sunday": "DaySunday",
        "day_monday": "DayMonday",
        "day_tuesday": "DayTuesday",
        "day_wednesday": "DayWednesday",
        "day_thursday": "DayThursday",
        "day_friday": "DayFriday",
        "day_saturday": "DaySaturday",
        "staff_id": "StaffId",
        "staff_pay_rate": "StaffPayRate",
        "resource_id": "ResourceId",
        "max_capacity": "MaxCapacity",
        "web_capacity": "WebCapacity",
        "waitlist_capacity": "WaitlistCapacity",
        "booking_status": "BookingStatus",
        "allow_open_enrollment": "AllowOpenEnrollment",
        "allow_date_forward_enrollment": "AllowDateForwardEnrollment",
        "pricing_options_product_ids": "PricingOptionsProductIds",
        "show_to_public": "ShowToPublic",
    }

    _optionals = [
        "class_description_id",
        "location_id",
        "start_date",
        "end_date",
        "start_time",
        "end_time",
        "day_sunday",
        "day_monday",
        "day_tuesday",
        "day_wednesday",
        "day_thursday",
        "day_friday",
        "day_saturday",
        "staff_id",
        "staff_pay_rate",
        "resource_id",
        "max_capacity",
        "web_capacity",
        "waitlist_capacity",
        "booking_status",
        "allow_open_enrollment",
        "allow_date_forward_enrollment",
        "pricing_options_product_ids",
        "show_to_public",
    ]

    def __init__(
        self,
        class_description_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        start_time=APIHelper.SKIP,
        end_time=APIHelper.SKIP,
        day_sunday=APIHelper.SKIP,
        day_monday=APIHelper.SKIP,
        day_tuesday=APIHelper.SKIP,
        day_wednesday=APIHelper.SKIP,
        day_thursday=APIHelper.SKIP,
        day_friday=APIHelper.SKIP,
        day_saturday=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        staff_pay_rate=APIHelper.SKIP,
        resource_id=APIHelper.SKIP,
        max_capacity=APIHelper.SKIP,
        web_capacity=APIHelper.SKIP,
        waitlist_capacity=APIHelper.SKIP,
        booking_status=APIHelper.SKIP,
        allow_open_enrollment=APIHelper.SKIP,
        allow_date_forward_enrollment=APIHelper.SKIP,
        pricing_options_product_ids=APIHelper.SKIP,
        show_to_public=APIHelper.SKIP):
        """Initialize a AddClassEnrollmentScheduleRequest instance."""
        # Initialize members of the class
        if class_description_id is not APIHelper.SKIP:
            self.class_description_id = class_description_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if start_time is not APIHelper.SKIP:
            self.start_time =\
                 APIHelper.apply_datetime_converter(
                start_time, APIHelper.RFC3339DateTime)\
                 if start_time else None
        if end_time is not APIHelper.SKIP:
            self.end_time =\
                 APIHelper.apply_datetime_converter(
                end_time, APIHelper.RFC3339DateTime)\
                 if end_time else None
        if day_sunday is not APIHelper.SKIP:
            self.day_sunday = day_sunday
        if day_monday is not APIHelper.SKIP:
            self.day_monday = day_monday
        if day_tuesday is not APIHelper.SKIP:
            self.day_tuesday = day_tuesday
        if day_wednesday is not APIHelper.SKIP:
            self.day_wednesday = day_wednesday
        if day_thursday is not APIHelper.SKIP:
            self.day_thursday = day_thursday
        if day_friday is not APIHelper.SKIP:
            self.day_friday = day_friday
        if day_saturday is not APIHelper.SKIP:
            self.day_saturday = day_saturday
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if staff_pay_rate is not APIHelper.SKIP:
            self.staff_pay_rate = staff_pay_rate
        if resource_id is not APIHelper.SKIP:
            self.resource_id = resource_id
        if max_capacity is not APIHelper.SKIP:
            self.max_capacity = max_capacity
        if web_capacity is not APIHelper.SKIP:
            self.web_capacity = web_capacity
        if waitlist_capacity is not APIHelper.SKIP:
            self.waitlist_capacity = waitlist_capacity
        if booking_status is not APIHelper.SKIP:
            self.booking_status = booking_status
        if allow_open_enrollment is not APIHelper.SKIP:
            self.allow_open_enrollment = allow_open_enrollment
        if allow_date_forward_enrollment is not APIHelper.SKIP:
            self.allow_date_forward_enrollment = allow_date_forward_enrollment
        if pricing_options_product_ids is not APIHelper.SKIP:
            self.pricing_options_product_ids = pricing_options_product_ids
        if show_to_public is not APIHelper.SKIP:
            self.show_to_public = show_to_public

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_description_id =\
            dictionary.get("ClassDescriptionId")\
            if dictionary.get("ClassDescriptionId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        start_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartTime")).datetime\
            if dictionary.get("StartTime") else APIHelper.SKIP
        end_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndTime")).datetime\
            if dictionary.get("EndTime") else APIHelper.SKIP
        day_sunday =\
            dictionary.get("DaySunday")\
            if "DaySunday" in dictionary.keys()\
                else APIHelper.SKIP
        day_monday =\
            dictionary.get("DayMonday")\
            if "DayMonday" in dictionary.keys()\
                else APIHelper.SKIP
        day_tuesday =\
            dictionary.get("DayTuesday")\
            if "DayTuesday" in dictionary.keys()\
                else APIHelper.SKIP
        day_wednesday =\
            dictionary.get("DayWednesday")\
            if "DayWednesday" in dictionary.keys()\
                else APIHelper.SKIP
        day_thursday =\
            dictionary.get("DayThursday")\
            if "DayThursday" in dictionary.keys()\
                else APIHelper.SKIP
        day_friday =\
            dictionary.get("DayFriday")\
            if "DayFriday" in dictionary.keys()\
                else APIHelper.SKIP
        day_saturday =\
            dictionary.get("DaySaturday")\
            if "DaySaturday" in dictionary.keys()\
                else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        staff_pay_rate =\
            dictionary.get("StaffPayRate")\
            if dictionary.get("StaffPayRate")\
                else APIHelper.SKIP
        resource_id =\
            dictionary.get("ResourceId")\
            if dictionary.get("ResourceId")\
                else APIHelper.SKIP
        max_capacity =\
            dictionary.get("MaxCapacity")\
            if dictionary.get("MaxCapacity")\
                else APIHelper.SKIP
        web_capacity =\
            dictionary.get("WebCapacity")\
            if dictionary.get("WebCapacity")\
                else APIHelper.SKIP
        waitlist_capacity =\
            dictionary.get("WaitlistCapacity")\
            if dictionary.get("WaitlistCapacity")\
                else APIHelper.SKIP
        booking_status =\
            dictionary.get("BookingStatus")\
            if dictionary.get("BookingStatus")\
                else APIHelper.SKIP
        allow_open_enrollment =\
            dictionary.get("AllowOpenEnrollment")\
            if "AllowOpenEnrollment" in dictionary.keys()\
                else APIHelper.SKIP
        allow_date_forward_enrollment =\
            dictionary.get("AllowDateForwardEnrollment")\
            if "AllowDateForwardEnrollment" in dictionary.keys()\
                else APIHelper.SKIP
        pricing_options_product_ids =\
            dictionary.get("PricingOptionsProductIds")\
            if dictionary.get("PricingOptionsProductIds")\
                else APIHelper.SKIP
        show_to_public =\
            dictionary.get("ShowToPublic")\
            if "ShowToPublic" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_description_id,
                   location_id,
                   start_date,
                   end_date,
                   start_time,
                   end_time,
                   day_sunday,
                   day_monday,
                   day_tuesday,
                   day_wednesday,
                   day_thursday,
                   day_friday,
                   day_saturday,
                   staff_id,
                   staff_pay_rate,
                   resource_id,
                   max_capacity,
                   web_capacity,
                   waitlist_capacity,
                   booking_status,
                   allow_open_enrollment,
                   allow_date_forward_enrollment,
                   pricing_options_product_ids,
                   show_to_public)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_description_id=(
            self.class_description_id
            if hasattr(self, "class_description_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _start_time=(
            self.start_time
            if hasattr(self, "start_time")
            else None
        )
        _end_time=(
            self.end_time
            if hasattr(self, "end_time")
            else None
        )
        _day_sunday=(
            self.day_sunday
            if hasattr(self, "day_sunday")
            else None
        )
        _day_monday=(
            self.day_monday
            if hasattr(self, "day_monday")
            else None
        )
        _day_tuesday=(
            self.day_tuesday
            if hasattr(self, "day_tuesday")
            else None
        )
        _day_wednesday=(
            self.day_wednesday
            if hasattr(self, "day_wednesday")
            else None
        )
        _day_thursday=(
            self.day_thursday
            if hasattr(self, "day_thursday")
            else None
        )
        _day_friday=(
            self.day_friday
            if hasattr(self, "day_friday")
            else None
        )
        _day_saturday=(
            self.day_saturday
            if hasattr(self, "day_saturday")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _staff_pay_rate=(
            self.staff_pay_rate
            if hasattr(self, "staff_pay_rate")
            else None
        )
        _resource_id=(
            self.resource_id
            if hasattr(self, "resource_id")
            else None
        )
        _max_capacity=(
            self.max_capacity
            if hasattr(self, "max_capacity")
            else None
        )
        _web_capacity=(
            self.web_capacity
            if hasattr(self, "web_capacity")
            else None
        )
        _waitlist_capacity=(
            self.waitlist_capacity
            if hasattr(self, "waitlist_capacity")
            else None
        )
        _booking_status=(
            self.booking_status
            if hasattr(self, "booking_status")
            else None
        )
        _allow_open_enrollment=(
            self.allow_open_enrollment
            if hasattr(self, "allow_open_enrollment")
            else None
        )
        _allow_date_forward_enrollment=(
            self.allow_date_forward_enrollment
            if hasattr(self, "allow_date_forward_enrollment")
            else None
        )
        _pricing_options_product_ids=(
            self.pricing_options_product_ids
            if hasattr(self, "pricing_options_product_ids")
            else None
        )
        _show_to_public=(
            self.show_to_public
            if hasattr(self, "show_to_public")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_description_id={_class_description_id!r}, "
            f"location_id={_location_id!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"start_time={_start_time!r}, "
            f"end_time={_end_time!r}, "
            f"day_sunday={_day_sunday!r}, "
            f"day_monday={_day_monday!r}, "
            f"day_tuesday={_day_tuesday!r}, "
            f"day_wednesday={_day_wednesday!r}, "
            f"day_thursday={_day_thursday!r}, "
            f"day_friday={_day_friday!r}, "
            f"day_saturday={_day_saturday!r}, "
            f"staff_id={_staff_id!r}, "
            f"staff_pay_rate={_staff_pay_rate!r}, "
            f"resource_id={_resource_id!r}, "
            f"max_capacity={_max_capacity!r}, "
            f"web_capacity={_web_capacity!r}, "
            f"waitlist_capacity={_waitlist_capacity!r}, "
            f"booking_status={_booking_status!r}, "
            f"allow_open_enrollment={_allow_open_enrollment!r}, "
            f"allow_date_forward_enrollment={_allow_date_forward_enrollment!r}, "
            f"pricing_options_product_ids={_pricing_options_product_ids!r}, "
            f"show_to_public={_show_to_public!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_description_id=(
            self.class_description_id
            if hasattr(self, "class_description_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _start_time=(
            self.start_time
            if hasattr(self, "start_time")
            else None
        )
        _end_time=(
            self.end_time
            if hasattr(self, "end_time")
            else None
        )
        _day_sunday=(
            self.day_sunday
            if hasattr(self, "day_sunday")
            else None
        )
        _day_monday=(
            self.day_monday
            if hasattr(self, "day_monday")
            else None
        )
        _day_tuesday=(
            self.day_tuesday
            if hasattr(self, "day_tuesday")
            else None
        )
        _day_wednesday=(
            self.day_wednesday
            if hasattr(self, "day_wednesday")
            else None
        )
        _day_thursday=(
            self.day_thursday
            if hasattr(self, "day_thursday")
            else None
        )
        _day_friday=(
            self.day_friday
            if hasattr(self, "day_friday")
            else None
        )
        _day_saturday=(
            self.day_saturday
            if hasattr(self, "day_saturday")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _staff_pay_rate=(
            self.staff_pay_rate
            if hasattr(self, "staff_pay_rate")
            else None
        )
        _resource_id=(
            self.resource_id
            if hasattr(self, "resource_id")
            else None
        )
        _max_capacity=(
            self.max_capacity
            if hasattr(self, "max_capacity")
            else None
        )
        _web_capacity=(
            self.web_capacity
            if hasattr(self, "web_capacity")
            else None
        )
        _waitlist_capacity=(
            self.waitlist_capacity
            if hasattr(self, "waitlist_capacity")
            else None
        )
        _booking_status=(
            self.booking_status
            if hasattr(self, "booking_status")
            else None
        )
        _allow_open_enrollment=(
            self.allow_open_enrollment
            if hasattr(self, "allow_open_enrollment")
            else None
        )
        _allow_date_forward_enrollment=(
            self.allow_date_forward_enrollment
            if hasattr(self, "allow_date_forward_enrollment")
            else None
        )
        _pricing_options_product_ids=(
            self.pricing_options_product_ids
            if hasattr(self, "pricing_options_product_ids")
            else None
        )
        _show_to_public=(
            self.show_to_public
            if hasattr(self, "show_to_public")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_description_id={_class_description_id!s}, "
            f"location_id={_location_id!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"start_time={_start_time!s}, "
            f"end_time={_end_time!s}, "
            f"day_sunday={_day_sunday!s}, "
            f"day_monday={_day_monday!s}, "
            f"day_tuesday={_day_tuesday!s}, "
            f"day_wednesday={_day_wednesday!s}, "
            f"day_thursday={_day_thursday!s}, "
            f"day_friday={_day_friday!s}, "
            f"day_saturday={_day_saturday!s}, "
            f"staff_id={_staff_id!s}, "
            f"staff_pay_rate={_staff_pay_rate!s}, "
            f"resource_id={_resource_id!s}, "
            f"max_capacity={_max_capacity!s}, "
            f"web_capacity={_web_capacity!s}, "
            f"waitlist_capacity={_waitlist_capacity!s}, "
            f"booking_status={_booking_status!s}, "
            f"allow_open_enrollment={_allow_open_enrollment!s}, "
            f"allow_date_forward_enrollment={_allow_date_forward_enrollment!s}, "
            f"pricing_options_product_ids={_pricing_options_product_ids!s}, "
            f"show_to_public={_show_to_public!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.api_error import (
    ApiError,
)
from mindbodypublicapi.models.mclass import (
    Class,
)
from mindbodypublicapi.models.pagination_response import (
    PaginationResponse,
)


class RemoveClientsFromClassesResponse(object):
    """Implementation of the 'RemoveClientsFromClassesResponse' model.

    Remove Clients From Classes Response

    Attributes:
        pagination_response (PaginationResponse): Contains information about the
            pagination to use.
        classes (List[Class]): Contains information about the classes from which the
            clients were removed.
        errors (List[ApiError]): Contains information about the errors

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "pagination_response": "PaginationResponse",
        "classes": "Classes",
        "errors": "Errors",
    }

    _optionals = [
        "pagination_response",
        "classes",
        "errors",
    ]

    def __init__(
        self,
        pagination_response=APIHelper.SKIP,
        classes=APIHelper.SKIP,
        errors=APIHelper.SKIP):
        """Initialize a RemoveClientsFromClassesResponse instance."""
        # Initialize members of the class
        if pagination_response is not APIHelper.SKIP:
            self.pagination_response = pagination_response
        if classes is not APIHelper.SKIP:
            self.classes = classes
        if errors is not APIHelper.SKIP:
            self.errors = errors

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        pagination_response =\
            PaginationResponse.from_dictionary(
                dictionary.get("PaginationResponse"))\
                if "PaginationResponse" in dictionary.keys()\
                else APIHelper.SKIP
        classes = None
        if dictionary.get("Classes") is not None:
            classes = [
                Class.from_dictionary(x)
                    for x in dictionary.get("Classes")
            ]
        else:
            classes = APIHelper.SKIP
        errors = None
        if dictionary.get("Errors") is not None:
            errors = [
                ApiError.from_dictionary(x)
                    for x in dictionary.get("Errors")
            ]
        else:
            errors = APIHelper.SKIP

        # Return an object of this model
        return cls(pagination_response,
                   classes,
                   errors)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _pagination_response=(
            self.pagination_response
            if hasattr(self, "pagination_response")
            else None
        )
        _classes=(
            self.classes
            if hasattr(self, "classes")
            else None
        )
        _errors=(
            self.errors
            if hasattr(self, "errors")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"pagination_response={_pagination_response!r}, "
            f"classes={_classes!r}, "
            f"errors={_errors!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _pagination_response=(
            self.pagination_response
            if hasattr(self, "pagination_response")
            else None
        )
        _classes=(
            self.classes
            if hasattr(self, "classes")
            else None
        )
        _errors=(
            self.errors
            if hasattr(self, "errors")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"pagination_response={_pagination_response!s}, "
            f"classes={_classes!s}, "
            f"errors={_errors!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AppointmentAddOn(object):
    """Implementation of the 'AppointmentAddOn' model.

    Attributes:
        id (int): The ID of this add-on.
        name (str): The name of this add-on.
        num_deducted (int): The number of sessions that this add-on deducts from the
            pricing option used to pay for this add-on.
        category_id (int): This ID of this add-on’s category.
        category (str): The name of this add-on’s category.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "name": "Name",
        "num_deducted": "NumDeducted",
        "category_id": "CategoryId",
        "category": "Category",
    }

    _optionals = [
        "id",
        "name",
        "num_deducted",
        "category_id",
        "category",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        num_deducted=APIHelper.SKIP,
        category_id=APIHelper.SKIP,
        category=APIHelper.SKIP):
        """Initialize a AppointmentAddOn instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if num_deducted is not APIHelper.SKIP:
            self.num_deducted = num_deducted
        if category_id is not APIHelper.SKIP:
            self.category_id = category_id
        if category is not APIHelper.SKIP:
            self.category = category

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        num_deducted =\
            dictionary.get("NumDeducted")\
            if dictionary.get("NumDeducted")\
                else APIHelper.SKIP
        category_id =\
            dictionary.get("CategoryId")\
            if dictionary.get("CategoryId")\
                else APIHelper.SKIP
        category =\
            dictionary.get("Category")\
            if dictionary.get("Category")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   name,
                   num_deducted,
                   category_id,
                   category)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _num_deducted=(
            self.num_deducted
            if hasattr(self, "num_deducted")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _category=(
            self.category
            if hasattr(self, "category")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"num_deducted={_num_deducted!r}, "
            f"category_id={_category_id!r}, "
            f"category={_category!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _num_deducted=(
            self.num_deducted
            if hasattr(self, "num_deducted")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _category=(
            self.category
            if hasattr(self, "category")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"num_deducted={_num_deducted!s}, "
            f"category_id={_category_id!s}, "
            f"category={_category!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: D410, E501, E101, D206
from apimatic_core.authentication.multiple.single_auth import (
    Single,
)
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter

from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.configuration import (
    Server,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.http.http_method_enum import (
    HttpMethodEnum,
)
from mindbodypublicapi.models.copy_credit_card_response import (
    CopyCreditCardResponse,
)


class CrossSiteController(BaseController):
    """A Controller to access Endpoints in the mindbodypublicapi API."""

    def __init__(self, config):
        """Initialize CrossSiteController object."""
        super(CrossSiteController, self).__init__(config)

    def copy_credit_card(self,
                         version,
                         request,
                         site_id,
                         authorization=None):
        """Perform a POST request to
        /public/v{version}/crossSite/copycreditcard.

        Copies the credit card information from one client to another, regardless of
        site.
        The source and target clients must have the same email address.

        Args:
            version (str): version of the api.
            request (CopyCreditCardRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            CopyCreditCardResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/crossSite/copycreditcard")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CopyCreditCardResponse.from_dictionary),
        ).execute()



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class CancelSingleClassRequest(object):
    """Implementation of the 'CancelSingleClassRequest' model.

    Attributes:
        class_id (int): Class ID to lookup.
        hide_cancel (bool): When `true`, indicates that this class is hidden when
            cancelled.  When `false`, indicates that this class is not hidden when
            cancelled.
        send_client_email (bool): When `true`, sends the client an automatic email
            about the cancellation, if the client has opted to receive email.
        send_staff_email (bool): When `true`, sends the staff an automatic email
            about the cancellation, if the staff has opted to receive email.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_id": "ClassID",
        "hide_cancel": "HideCancel",
        "send_client_email": "SendClientEmail",
        "send_staff_email": "SendStaffEmail",
    }

    _optionals = [
        "class_id",
        "hide_cancel",
        "send_client_email",
        "send_staff_email",
    ]

    def __init__(
        self,
        class_id=APIHelper.SKIP,
        hide_cancel=APIHelper.SKIP,
        send_client_email=APIHelper.SKIP,
        send_staff_email=APIHelper.SKIP):
        """Initialize a CancelSingleClassRequest instance."""
        # Initialize members of the class
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        if hide_cancel is not APIHelper.SKIP:
            self.hide_cancel = hide_cancel
        if send_client_email is not APIHelper.SKIP:
            self.send_client_email = send_client_email
        if send_staff_email is not APIHelper.SKIP:
            self.send_staff_email = send_staff_email

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_id =\
            dictionary.get("ClassID")\
            if dictionary.get("ClassID")\
                else APIHelper.SKIP
        hide_cancel =\
            dictionary.get("HideCancel")\
            if "HideCancel" in dictionary.keys()\
                else APIHelper.SKIP
        send_client_email =\
            dictionary.get("SendClientEmail")\
            if "SendClientEmail" in dictionary.keys()\
                else APIHelper.SKIP
        send_staff_email =\
            dictionary.get("SendStaffEmail")\
            if "SendStaffEmail" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_id,
                   hide_cancel,
                   send_client_email,
                   send_staff_email)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _hide_cancel=(
            self.hide_cancel
            if hasattr(self, "hide_cancel")
            else None
        )
        _send_client_email=(
            self.send_client_email
            if hasattr(self, "send_client_email")
            else None
        )
        _send_staff_email=(
            self.send_staff_email
            if hasattr(self, "send_staff_email")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_id={_class_id!r}, "
            f"hide_cancel={_hide_cancel!r}, "
            f"send_client_email={_send_client_email!r}, "
            f"send_staff_email={_send_staff_email!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _hide_cancel=(
            self.hide_cancel
            if hasattr(self, "hide_cancel")
            else None
        )
        _send_client_email=(
            self.send_client_email
            if hasattr(self, "send_client_email")
            else None
        )
        _send_staff_email=(
            self.send_staff_email
            if hasattr(self, "send_staff_email")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_id={_class_id!s}, "
            f"hide_cancel={_hide_cancel!s}, "
            f"send_client_email={_send_client_email!s}, "
            f"send_staff_email={_send_staff_email!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.gift_card_layout import (
    GiftCardLayout,
)


class GiftCard(object):
    """Implementation of the 'GiftCard' model.

    Attributes:
        id (int): The gift card's `ProductID`.
        location_ids (List[int]): The IDs of the locations where the gift card is
            sold.
        description (str): A description of the gift card.
        editable_by_consumer (bool): When `true`, indicates that the gift card can be
            edited by the client.
        card_value (float): The value of the gift card.
        sale_price (float): The sale price of the gift card, if applicable.
        sold_online (bool): When `true`, indicates that the gift card is sold online.
        membership_restriction_ids (List[int]): A list of IDs for membership
            restrictions, if this card is restricted to members with certain types of
            memberships.
        gift_card_terms (str): The terms of the gift card.
        contact_info (str): Contact information for the gift card.
        display_logo (bool): When `true`, indicates that the logo should be displayed
            on the gift card.
        layouts (List[GiftCardLayout]): A list of layouts available for the gift card.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "location_ids": "LocationIds",
        "description": "Description",
        "editable_by_consumer": "EditableByConsumer",
        "card_value": "CardValue",
        "sale_price": "SalePrice",
        "sold_online": "SoldOnline",
        "membership_restriction_ids": "MembershipRestrictionIds",
        "gift_card_terms": "GiftCardTerms",
        "contact_info": "ContactInfo",
        "display_logo": "DisplayLogo",
        "layouts": "Layouts",
    }

    _optionals = [
        "id",
        "location_ids",
        "description",
        "editable_by_consumer",
        "card_value",
        "sale_price",
        "sold_online",
        "membership_restriction_ids",
        "gift_card_terms",
        "contact_info",
        "display_logo",
        "layouts",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        location_ids=APIHelper.SKIP,
        description=APIHelper.SKIP,
        editable_by_consumer=APIHelper.SKIP,
        card_value=APIHelper.SKIP,
        sale_price=APIHelper.SKIP,
        sold_online=APIHelper.SKIP,
        membership_restriction_ids=APIHelper.SKIP,
        gift_card_terms=APIHelper.SKIP,
        contact_info=APIHelper.SKIP,
        display_logo=APIHelper.SKIP,
        layouts=APIHelper.SKIP):
        """Initialize a GiftCard instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if location_ids is not APIHelper.SKIP:
            self.location_ids = location_ids
        if description is not APIHelper.SKIP:
            self.description = description
        if editable_by_consumer is not APIHelper.SKIP:
            self.editable_by_consumer = editable_by_consumer
        if card_value is not APIHelper.SKIP:
            self.card_value = card_value
        if sale_price is not APIHelper.SKIP:
            self.sale_price = sale_price
        if sold_online is not APIHelper.SKIP:
            self.sold_online = sold_online
        if membership_restriction_ids is not APIHelper.SKIP:
            self.membership_restriction_ids = membership_restriction_ids
        if gift_card_terms is not APIHelper.SKIP:
            self.gift_card_terms = gift_card_terms
        if contact_info is not APIHelper.SKIP:
            self.contact_info = contact_info
        if display_logo is not APIHelper.SKIP:
            self.display_logo = display_logo
        if layouts is not APIHelper.SKIP:
            self.layouts = layouts

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        location_ids =\
            dictionary.get("LocationIds")\
            if dictionary.get("LocationIds")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        editable_by_consumer =\
            dictionary.get("EditableByConsumer")\
            if "EditableByConsumer" in dictionary.keys()\
                else APIHelper.SKIP
        card_value =\
            dictionary.get("CardValue")\
            if dictionary.get("CardValue")\
                else APIHelper.SKIP
        sale_price =\
            dictionary.get("SalePrice")\
            if dictionary.get("SalePrice")\
                else APIHelper.SKIP
        sold_online =\
            dictionary.get("SoldOnline")\
            if "SoldOnline" in dictionary.keys()\
                else APIHelper.SKIP
        membership_restriction_ids =\
            dictionary.get("MembershipRestrictionIds")\
            if dictionary.get("MembershipRestrictionIds")\
                else APIHelper.SKIP
        gift_card_terms =\
            dictionary.get("GiftCardTerms")\
            if dictionary.get("GiftCardTerms")\
                else APIHelper.SKIP
        contact_info =\
            dictionary.get("ContactInfo")\
            if dictionary.get("ContactInfo")\
                else APIHelper.SKIP
        display_logo =\
            dictionary.get("DisplayLogo")\
            if "DisplayLogo" in dictionary.keys()\
                else APIHelper.SKIP
        layouts = None
        if dictionary.get("Layouts") is not None:
            layouts = [
                GiftCardLayout.from_dictionary(x)
                    for x in dictionary.get("Layouts")
            ]
        else:
            layouts = APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   location_ids,
                   description,
                   editable_by_consumer,
                   card_value,
                   sale_price,
                   sold_online,
                   membership_restriction_ids,
                   gift_card_terms,
                   contact_info,
                   display_logo,
                   layouts)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _editable_by_consumer=(
            self.editable_by_consumer
            if hasattr(self, "editable_by_consumer")
            else None
        )
        _card_value=(
            self.card_value
            if hasattr(self, "card_value")
            else None
        )
        _sale_price=(
            self.sale_price
            if hasattr(self, "sale_price")
            else None
        )
        _sold_online=(
            self.sold_online
            if hasattr(self, "sold_online")
            else None
        )
        _membership_restriction_ids=(
            self.membership_restriction_ids
            if hasattr(self, "membership_restriction_ids")
            else None
        )
        _gift_card_terms=(
            self.gift_card_terms
            if hasattr(self, "gift_card_terms")
            else None
        )
        _contact_info=(
            self.contact_info
            if hasattr(self, "contact_info")
            else None
        )
        _display_logo=(
            self.display_logo
            if hasattr(self, "display_logo")
            else None
        )
        _layouts=(
            self.layouts
            if hasattr(self, "layouts")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"location_ids={_location_ids!r}, "
            f"description={_description!r}, "
            f"editable_by_consumer={_editable_by_consumer!r}, "
            f"card_value={_card_value!r}, "
            f"sale_price={_sale_price!r}, "
            f"sold_online={_sold_online!r}, "
            f"membership_restriction_ids={_membership_restriction_ids!r}, "
            f"gift_card_terms={_gift_card_terms!r}, "
            f"contact_info={_contact_info!r}, "
            f"display_logo={_display_logo!r}, "
            f"layouts={_layouts!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _editable_by_consumer=(
            self.editable_by_consumer
            if hasattr(self, "editable_by_consumer")
            else None
        )
        _card_value=(
            self.card_value
            if hasattr(self, "card_value")
            else None
        )
        _sale_price=(
            self.sale_price
            if hasattr(self, "sale_price")
            else None
        )
        _sold_online=(
            self.sold_online
            if hasattr(self, "sold_online")
            else None
        )
        _membership_restriction_ids=(
            self.membership_restriction_ids
            if hasattr(self, "membership_restriction_ids")
            else None
        )
        _gift_card_terms=(
            self.gift_card_terms
            if hasattr(self, "gift_card_terms")
            else None
        )
        _contact_info=(
            self.contact_info
            if hasattr(self, "contact_info")
            else None
        )
        _display_logo=(
            self.display_logo
            if hasattr(self, "display_logo")
            else None
        )
        _layouts=(
            self.layouts
            if hasattr(self, "layouts")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"location_ids={_location_ids!s}, "
            f"description={_description!s}, "
            f"editable_by_consumer={_editable_by_consumer!s}, "
            f"card_value={_card_value!s}, "
            f"sale_price={_sale_price!s}, "
            f"sold_online={_sold_online!s}, "
            f"membership_restriction_ids={_membership_restriction_ids!s}, "
            f"gift_card_terms={_gift_card_terms!s}, "
            f"contact_info={_contact_info!s}, "
            f"display_logo={_display_logo!s}, "
            f"layouts={_layouts!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetWaitlistEntriesRequest(object):
    """Implementation of the 'GetWaitlistEntriesRequest' model.

    Attributes:
        class_ids (List[int]): The requested class IDs. If a class ID is present, the
            request automatically disregards any class schedule IDs in the request.
            <br />  Either `ClassScheduleIds`, `ClientIds`, `WaitlistEntryIds`, or
            `ClassIds` is required; the others become optional.<br />  Default: **all
            ClassIds**
        class_schedule_ids (List[int]): The requested class schedule IDs. If a class
            ID is present, the request automatically disregards any class schedule
            IDs in the request.<br />  Either `ClassScheduleIds`, `ClientIds`,
            `WaitlistEntryIds`, or `ClassIds` is required; the others become
            optional.<br />  Default: **all ClassScheduleIds**
        client_ids (List[str]): The requested client IDs.<br />  Either
            `ClassScheduleIds`, `ClientIds`, `WaitlistEntryIds`, or `ClassIds` is
            required; the others become optional.<br />  Default: **all ClientIds**
        hide_past_entries (bool): When `true`, indicates that past waiting list
            entries are hidden from clients.<br />  When `false`, indicates that past
            entries are not hidden from clients.<br />  Default: **false**
        waitlist_entry_ids (List[int]): The requested waiting list entry IDs.<br />
            Either `ClassScheduleIds`, `ClientIds`, `WaitlistEntryIds`, or `ClassIds`
            is required; the others become optional.<br />  Default: **all
            WaitlistEntryIds**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_ids": "ClassIds",
        "class_schedule_ids": "ClassScheduleIds",
        "client_ids": "ClientIds",
        "hide_past_entries": "HidePastEntries",
        "waitlist_entry_ids": "WaitlistEntryIds",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "class_ids",
        "class_schedule_ids",
        "client_ids",
        "hide_past_entries",
        "waitlist_entry_ids",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        class_ids=APIHelper.SKIP,
        class_schedule_ids=APIHelper.SKIP,
        client_ids=APIHelper.SKIP,
        hide_past_entries=APIHelper.SKIP,
        waitlist_entry_ids=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetWaitlistEntriesRequest instance."""
        # Initialize members of the class
        if class_ids is not APIHelper.SKIP:
            self.class_ids = class_ids
        if class_schedule_ids is not APIHelper.SKIP:
            self.class_schedule_ids = class_schedule_ids
        if client_ids is not APIHelper.SKIP:
            self.client_ids = client_ids
        if hide_past_entries is not APIHelper.SKIP:
            self.hide_past_entries = hide_past_entries
        if waitlist_entry_ids is not APIHelper.SKIP:
            self.waitlist_entry_ids = waitlist_entry_ids
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_ids =\
            dictionary.get("ClassIds")\
            if dictionary.get("ClassIds")\
                else APIHelper.SKIP
        class_schedule_ids =\
            dictionary.get("ClassScheduleIds")\
            if dictionary.get("ClassScheduleIds")\
                else APIHelper.SKIP
        client_ids =\
            dictionary.get("ClientIds")\
            if dictionary.get("ClientIds")\
                else APIHelper.SKIP
        hide_past_entries =\
            dictionary.get("HidePastEntries")\
            if "HidePastEntries" in dictionary.keys()\
                else APIHelper.SKIP
        waitlist_entry_ids =\
            dictionary.get("WaitlistEntryIds")\
            if dictionary.get("WaitlistEntryIds")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_ids,
                   class_schedule_ids,
                   client_ids,
                   hide_past_entries,
                   waitlist_entry_ids,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_ids=(
            self.class_ids
            if hasattr(self, "class_ids")
            else None
        )
        _class_schedule_ids=(
            self.class_schedule_ids
            if hasattr(self, "class_schedule_ids")
            else None
        )
        _client_ids=(
            self.client_ids
            if hasattr(self, "client_ids")
            else None
        )
        _hide_past_entries=(
            self.hide_past_entries
            if hasattr(self, "hide_past_entries")
            else None
        )
        _waitlist_entry_ids=(
            self.waitlist_entry_ids
            if hasattr(self, "waitlist_entry_ids")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_ids={_class_ids!r}, "
            f"class_schedule_ids={_class_schedule_ids!r}, "
            f"client_ids={_client_ids!r}, "
            f"hide_past_entries={_hide_past_entries!r}, "
            f"waitlist_entry_ids={_waitlist_entry_ids!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_ids=(
            self.class_ids
            if hasattr(self, "class_ids")
            else None
        )
        _class_schedule_ids=(
            self.class_schedule_ids
            if hasattr(self, "class_schedule_ids")
            else None
        )
        _client_ids=(
            self.client_ids
            if hasattr(self, "client_ids")
            else None
        )
        _hide_past_entries=(
            self.hide_past_entries
            if hasattr(self, "hide_past_entries")
            else None
        )
        _waitlist_entry_ids=(
            self.waitlist_entry_ids
            if hasattr(self, "waitlist_entry_ids")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_ids={_class_ids!s}, "
            f"class_schedule_ids={_class_schedule_ids!s}, "
            f"client_ids={_client_ids!s}, "
            f"hide_past_entries={_hide_past_entries!s}, "
            f"waitlist_entry_ids={_waitlist_entry_ids!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class DeleteContactLogRequest(object):
    """Implementation of the 'DeleteContactLogRequest' model.

    Attributes:
        client_id (str): The client ID of the client whose Contact Log is being
            deleted.
        contact_log_id (int): The Contact Log ID.
        test (bool): When `true`, indicates that this is a test request and no data
            is inserted into the subscriber’s database.  When `false`, the database
            is updated.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "contact_log_id": "ContactLogId",
        "test": "Test",
    }

    _optionals = [
        "test",
    ]

    def __init__(
        self,
        client_id=None,
        contact_log_id=None,
        test=APIHelper.SKIP):
        """Initialize a DeleteContactLogRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        self.contact_log_id = contact_log_id
        if test is not APIHelper.SKIP:
            self.test = test

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        contact_log_id =\
            dictionary.get("ContactLogId")\
            if dictionary.get("ContactLogId")\
                else None
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   contact_log_id,
                   test)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _contact_log_id=self.contact_log_id
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"contact_log_id={_contact_log_id!r}, "
            f"test={_test!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _contact_log_id=self.contact_log_id
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"contact_log_id={_contact_log_id!s}, "
            f"test={_test!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AssignStaffSessionTypeResponse(object):
    """Implementation of the 'AssignStaffSessionTypeResponse' model.

    Attributes:
        staff_id (int): Staff member assigned to the session type
        session_type_id (int): The session type the staff member is assigned to
        pay_rate_type (str): The pay rate type name  Can be: "Flat", "Percent", or
            "No Pay"
        pay_rate_amount (float): The pay rate amount. It is interpreted based on the
            value of PayRateTypeId
        time_length (int): The staff specific amount of time that a session of this
            type typically lasts.
        prep_time (int): Prep time in minutes
        finish_time (int): Finish time in minutes
        active (bool): Whether this association is active

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "session_type_id": "SessionTypeId",
        "pay_rate_type": "PayRateType",
        "pay_rate_amount": "PayRateAmount",
        "time_length": "TimeLength",
        "prep_time": "PrepTime",
        "finish_time": "FinishTime",
        "active": "Active",
    }

    _optionals = [
        "staff_id",
        "session_type_id",
        "pay_rate_type",
        "pay_rate_amount",
        "time_length",
        "prep_time",
        "finish_time",
        "active",
    ]

    def __init__(
        self,
        staff_id=APIHelper.SKIP,
        session_type_id=APIHelper.SKIP,
        pay_rate_type=APIHelper.SKIP,
        pay_rate_amount=APIHelper.SKIP,
        time_length=APIHelper.SKIP,
        prep_time=APIHelper.SKIP,
        finish_time=APIHelper.SKIP,
        active=APIHelper.SKIP):
        """Initialize a AssignStaffSessionTypeResponse instance."""
        # Initialize members of the class
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if session_type_id is not APIHelper.SKIP:
            self.session_type_id = session_type_id
        if pay_rate_type is not APIHelper.SKIP:
            self.pay_rate_type = pay_rate_type
        if pay_rate_amount is not APIHelper.SKIP:
            self.pay_rate_amount = pay_rate_amount
        if time_length is not APIHelper.SKIP:
            self.time_length = time_length
        if prep_time is not APIHelper.SKIP:
            self.prep_time = prep_time
        if finish_time is not APIHelper.SKIP:
            self.finish_time = finish_time
        if active is not APIHelper.SKIP:
            self.active = active

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else APIHelper.SKIP
        pay_rate_type =\
            dictionary.get("PayRateType")\
            if dictionary.get("PayRateType")\
                else APIHelper.SKIP
        pay_rate_amount =\
            dictionary.get("PayRateAmount")\
            if dictionary.get("PayRateAmount")\
                else APIHelper.SKIP
        time_length =\
            dictionary.get("TimeLength")\
            if dictionary.get("TimeLength")\
                else APIHelper.SKIP
        prep_time =\
            dictionary.get("PrepTime")\
            if dictionary.get("PrepTime")\
                else APIHelper.SKIP
        finish_time =\
            dictionary.get("FinishTime")\
            if dictionary.get("FinishTime")\
                else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id,
                   session_type_id,
                   pay_rate_type,
                   pay_rate_amount,
                   time_length,
                   prep_time,
                   finish_time,
                   active)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _pay_rate_type=(
            self.pay_rate_type
            if hasattr(self, "pay_rate_type")
            else None
        )
        _pay_rate_amount=(
            self.pay_rate_amount
            if hasattr(self, "pay_rate_amount")
            else None
        )
        _time_length=(
            self.time_length
            if hasattr(self, "time_length")
            else None
        )
        _prep_time=(
            self.prep_time
            if hasattr(self, "prep_time")
            else None
        )
        _finish_time=(
            self.finish_time
            if hasattr(self, "finish_time")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"session_type_id={_session_type_id!r}, "
            f"pay_rate_type={_pay_rate_type!r}, "
            f"pay_rate_amount={_pay_rate_amount!r}, "
            f"time_length={_time_length!r}, "
            f"prep_time={_prep_time!r}, "
            f"finish_time={_finish_time!r}, "
            f"active={_active!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _pay_rate_type=(
            self.pay_rate_type
            if hasattr(self, "pay_rate_type")
            else None
        )
        _pay_rate_amount=(
            self.pay_rate_amount
            if hasattr(self, "pay_rate_amount")
            else None
        )
        _time_length=(
            self.time_length
            if hasattr(self, "time_length")
            else None
        )
        _prep_time=(
            self.prep_time
            if hasattr(self, "prep_time")
            else None
        )
        _finish_time=(
            self.finish_time
            if hasattr(self, "finish_time")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"session_type_id={_session_type_id!s}, "
            f"pay_rate_type={_pay_rate_type!s}, "
            f"pay_rate_amount={_pay_rate_amount!s}, "
            f"time_length={_time_length!s}, "
            f"prep_time={_prep_time!s}, "
            f"finish_time={_finish_time!s}, "
            f"active={_active!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.program import (
    Program,
)


class ClientService(object):
    """Implementation of the 'ClientService' model.

    A service that is on a client's account.

    Attributes:
        active_date (datetime): The date that this pricing option became active and
            could be used to pay for services.
        count (int): The number of service sessions this pricing option contained
            when first purchased.
        current (bool): When `true`, there are service sessions remaining on the
            pricing option that can be used pay for the current session.<br />  When
            `false`, the client cannot use this pricing option to pay for other
            services.
        expiration_date (datetime): The date when the pricing option expires and can
            no longer be used to pay for services, even if unused service sessions
            remain on the option; expressed as UTC.
        id (int): The unique ID assigned to this pricing option, specific to when it
            was purchased by the client.
        product_id (int): The unique ID of this pricing option, not specific to any
            client's purchase of it.
        name (str): The name of this pricing option.
        payment_date (datetime): The date on which the client paid for this pricing
            option.
        program (Program): The model property of type Program.
        remaining (int): The number of service sessions remaining in the pricing
            option that can still be used.
        site_id (int): The ID of the subscriber site associated with this pricing
            option.
        action (Action1Enum): The action taken.
        client_id (str): The Client ID assigned to this pricing option, specific to
            when it was purchased by the client.
        returned (bool): Identification for purchased service is returned or not.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "active_date": "ActiveDate",
        "count": "Count",
        "current": "Current",
        "expiration_date": "ExpirationDate",
        "id": "Id",
        "product_id": "ProductId",
        "name": "Name",
        "payment_date": "PaymentDate",
        "program": "Program",
        "remaining": "Remaining",
        "site_id": "SiteId",
        "action": "Action",
        "client_id": "ClientID",
        "returned": "Returned",
    }

    _optionals = [
        "active_date",
        "count",
        "current",
        "expiration_date",
        "id",
        "product_id",
        "name",
        "payment_date",
        "program",
        "remaining",
        "site_id",
        "action",
        "client_id",
        "returned",
    ]

    def __init__(
        self,
        active_date=APIHelper.SKIP,
        count=APIHelper.SKIP,
        current=APIHelper.SKIP,
        expiration_date=APIHelper.SKIP,
        id=APIHelper.SKIP,
        product_id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        payment_date=APIHelper.SKIP,
        program=APIHelper.SKIP,
        remaining=APIHelper.SKIP,
        site_id=APIHelper.SKIP,
        action=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        returned=APIHelper.SKIP):
        """Initialize a ClientService instance."""
        # Initialize members of the class
        if active_date is not APIHelper.SKIP:
            self.active_date =\
                 APIHelper.apply_datetime_converter(
                active_date, APIHelper.RFC3339DateTime)\
                 if active_date else None
        if count is not APIHelper.SKIP:
            self.count = count
        if current is not APIHelper.SKIP:
            self.current = current
        if expiration_date is not APIHelper.SKIP:
            self.expiration_date =\
                 APIHelper.apply_datetime_converter(
                expiration_date, APIHelper.RFC3339DateTime)\
                 if expiration_date else None
        if id is not APIHelper.SKIP:
            self.id = id
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id
        if name is not APIHelper.SKIP:
            self.name = name
        if payment_date is not APIHelper.SKIP:
            self.payment_date =\
                 APIHelper.apply_datetime_converter(
                payment_date, APIHelper.RFC3339DateTime)\
                 if payment_date else None
        if program is not APIHelper.SKIP:
            self.program = program
        if remaining is not APIHelper.SKIP:
            self.remaining = remaining
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id
        if action is not APIHelper.SKIP:
            self.action = action
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if returned is not APIHelper.SKIP:
            self.returned = returned

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        active_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ActiveDate")).datetime\
            if dictionary.get("ActiveDate") else APIHelper.SKIP
        count =\
            dictionary.get("Count")\
            if dictionary.get("Count")\
                else APIHelper.SKIP
        current =\
            dictionary.get("Current")\
            if "Current" in dictionary.keys()\
                else APIHelper.SKIP
        expiration_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ExpirationDate")).datetime\
            if dictionary.get("ExpirationDate") else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        payment_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("PaymentDate")).datetime\
            if dictionary.get("PaymentDate") else APIHelper.SKIP
        program =\
            Program.from_dictionary(
                dictionary.get("Program"))\
                if "Program" in dictionary.keys()\
                else APIHelper.SKIP
        remaining =\
            dictionary.get("Remaining")\
            if dictionary.get("Remaining")\
                else APIHelper.SKIP
        site_id =\
            dictionary.get("SiteId")\
            if dictionary.get("SiteId")\
                else APIHelper.SKIP
        action =\
            dictionary.get("Action")\
            if dictionary.get("Action")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientID")\
            if dictionary.get("ClientID")\
                else APIHelper.SKIP
        returned =\
            dictionary.get("Returned")\
            if "Returned" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(active_date,
                   count,
                   current,
                   expiration_date,
                   id,
                   product_id,
                   name,
                   payment_date,
                   program,
                   remaining,
                   site_id,
                   action,
                   client_id,
                   returned)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _active_date=(
            self.active_date
            if hasattr(self, "active_date")
            else None
        )
        _count=(
            self.count
            if hasattr(self, "count")
            else None
        )
        _current=(
            self.current
            if hasattr(self, "current")
            else None
        )
        _expiration_date=(
            self.expiration_date
            if hasattr(self, "expiration_date")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _payment_date=(
            self.payment_date
            if hasattr(self, "payment_date")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _remaining=(
            self.remaining
            if hasattr(self, "remaining")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _returned=(
            self.returned
            if hasattr(self, "returned")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"active_date={_active_date!r}, "
            f"count={_count!r}, "
            f"current={_current!r}, "
            f"expiration_date={_expiration_date!r}, "
            f"id={_id!r}, "
            f"product_id={_product_id!r}, "
            f"name={_name!r}, "
            f"payment_date={_payment_date!r}, "
            f"program={_program!r}, "
            f"remaining={_remaining!r}, "
            f"site_id={_site_id!r}, "
            f"action={_action!r}, "
            f"client_id={_client_id!r}, "
            f"returned={_returned!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _active_date=(
            self.active_date
            if hasattr(self, "active_date")
            else None
        )
        _count=(
            self.count
            if hasattr(self, "count")
            else None
        )
        _current=(
            self.current
            if hasattr(self, "current")
            else None
        )
        _expiration_date=(
            self.expiration_date
            if hasattr(self, "expiration_date")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _payment_date=(
            self.payment_date
            if hasattr(self, "payment_date")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _remaining=(
            self.remaining
            if hasattr(self, "remaining")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _returned=(
            self.returned
            if hasattr(self, "returned")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"active_date={_active_date!s}, "
            f"count={_count!s}, "
            f"current={_current!s}, "
            f"expiration_date={_expiration_date!s}, "
            f"id={_id!s}, "
            f"product_id={_product_id!s}, "
            f"name={_name!s}, "
            f"payment_date={_payment_date!s}, "
            f"program={_program!s}, "
            f"remaining={_remaining!s}, "
            f"site_id={_site_id!s}, "
            f"action={_action!s}, "
            f"client_id={_client_id!s}, "
            f"returned={_returned!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501

class AppointmentGenderPreferenceEnum(object):
    """Implementation of the 'AppointmentGenderPreference' enum.

    The gender of staff member with whom the client prefers to book appointments.
    Possible values are:
    * Female - Indicates that the client prefers to book appointments with female
    staff members.
    * Male - Indicates that the client prefers to book appointments with male staff
    members.
    * None - Indicates that the client does not have a staff member gender preference.

    Attributes:
        NONE: The enum member of type str.
        FEMALE: The enum member of type str.
        MALE: The enum member of type str.

    """

    ENUM_NONE = "None"

    FEMALE = "Female"

    MALE = "Male"

    @classmethod
    def from_value(cls, value, default=None):
        """Return the matching enum value for the given input."""
        if value is None:
            return default

        # If numeric and matches directly
        if isinstance(value, int):
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and val == value:
                    return val

        # If string, perform case-insensitive match
        if isinstance(value, str):
            value_lower = value.lower()
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and (
                    name.lower() == value_lower or str(val).lower() == value_lower
                ):
                    return val

        # Fallback to default
        return default



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class WrittenClassSchedulesInfo(object):
    """Implementation of the 'WrittenClassSchedulesInfo' model.

    Attributes:
        class_id (int): The ClassScheduleId.
        class_instance_ids (List[int]): The individual ClassIds of the enrollment
            schedule.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_id": "ClassId",
        "class_instance_ids": "ClassInstanceIds",
    }

    _optionals = [
        "class_id",
        "class_instance_ids",
    ]

    def __init__(
        self,
        class_id=APIHelper.SKIP,
        class_instance_ids=APIHelper.SKIP):
        """Initialize a WrittenClassSchedulesInfo instance."""
        # Initialize members of the class
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        if class_instance_ids is not APIHelper.SKIP:
            self.class_instance_ids = class_instance_ids

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else APIHelper.SKIP
        class_instance_ids =\
            dictionary.get("ClassInstanceIds")\
            if dictionary.get("ClassInstanceIds")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_id,
                   class_instance_ids)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_instance_ids=(
            self.class_instance_ids
            if hasattr(self, "class_instance_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_id={_class_id!r}, "
            f"class_instance_ids={_class_instance_ids!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_instance_ids=(
            self.class_instance_ids
            if hasattr(self, "class_instance_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_id={_class_id!s}, "
            f"class_instance_ids={_class_instance_ids!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddClientToClassRequest(object):
    """Implementation of the 'AddClientToClassRequest' model.

    Attributes:
        client_id (str): The ID of the client who is being booked into the class
        class_id (int): The ID of the class into which the client is being booked
        test (bool): When `true`, indicates that input information is validated, but
            not committed.<br />  When `false`, the information is committed and the
            database is affected.<br />  Default: **false**
        require_payment (bool): When `true`, the client must have an active, usable
            pricing option on their account.<br />  When `false` or omitted, an
            active pricing option is not required to complete the client’s booking.
        waitlist (bool): When `true`, indicates that the client should be added to a
            specific class waiting list.<br />  When `false`, the client should not
            be added to the waiting list.
        send_email (bool): When `true`, the subscriber’s configured Booking
            Confirmation automatic email is sent to the client. Note that an email is
            sent only if the client has an email address and automatic emails have
            been set up.<br />  When `false`, indicates that the client does not
            receive emails.<br />  Default: **false**  **Note**: When the
            Authorization header is passed and the SendEmail is set to `true`, then
            an email will be sent.  When the Authorization header is passed and the
            SendEmail is set to `false`, then an email will not be sent.  When the
            Authorization header is not passed and the SendEmail is set to either
            `true` or `false`, then an email will not be sent.
        waitlist_entry_id (int): The ID of the waiting list entry from which you are
            moving a client into a class.
        client_service_id (int): The ID of the pricing option on the client’s account
            that you want to use to pay for this booking, if payment is required at
            the time of the update.
        cross_regional_booking (bool): When `true`, cross regional series are checked
            and used if applicable.
        cross_regional_booking_client_service_site_id (int): If the request is cross
            regional, use a purchased pricing option from this specified site. If
            omitted, an attempt is made to use an applicable pricing option from the
            local site.
        unique_id (int): The UniqueID of the client who is being booked into the class

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "class_id": "ClassId",
        "test": "Test",
        "require_payment": "RequirePayment",
        "waitlist": "Waitlist",
        "send_email": "SendEmail",
        "waitlist_entry_id": "WaitlistEntryId",
        "client_service_id": "ClientServiceId",
        "cross_regional_booking": "CrossRegionalBooking",
        "cross_regional_booking_client_service_site_id":
            "CrossRegionalBookingClientServiceSiteId",
        "unique_id": "UniqueId",
    }

    _optionals = [
        "test",
        "require_payment",
        "waitlist",
        "send_email",
        "waitlist_entry_id",
        "client_service_id",
        "cross_regional_booking",
        "cross_regional_booking_client_service_site_id",
        "unique_id",
    ]

    def __init__(
        self,
        client_id=None,
        class_id=None,
        test=APIHelper.SKIP,
        require_payment=APIHelper.SKIP,
        waitlist=APIHelper.SKIP,
        send_email=APIHelper.SKIP,
        waitlist_entry_id=APIHelper.SKIP,
        client_service_id=APIHelper.SKIP,
        cross_regional_booking=APIHelper.SKIP,
        cross_regional_booking_client_service_site_id=APIHelper.SKIP,
        unique_id=APIHelper.SKIP):
        """Initialize a AddClientToClassRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        self.class_id = class_id
        if test is not APIHelper.SKIP:
            self.test = test
        if require_payment is not APIHelper.SKIP:
            self.require_payment = require_payment
        if waitlist is not APIHelper.SKIP:
            self.waitlist = waitlist
        if send_email is not APIHelper.SKIP:
            self.send_email = send_email
        if waitlist_entry_id is not APIHelper.SKIP:
            self.waitlist_entry_id = waitlist_entry_id
        if client_service_id is not APIHelper.SKIP:
            self.client_service_id = client_service_id
        if cross_regional_booking is not APIHelper.SKIP:
            self.cross_regional_booking = cross_regional_booking
        if cross_regional_booking_client_service_site_id is not APIHelper.SKIP:
            self.cross_regional_booking_client_service_site_id =\
                 cross_regional_booking_client_service_site_id
        if unique_id is not APIHelper.SKIP:
            self.unique_id = unique_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else None
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        require_payment =\
            dictionary.get("RequirePayment")\
            if "RequirePayment" in dictionary.keys()\
                else APIHelper.SKIP
        waitlist =\
            dictionary.get("Waitlist")\
            if "Waitlist" in dictionary.keys()\
                else APIHelper.SKIP
        send_email =\
            dictionary.get("SendEmail")\
            if "SendEmail" in dictionary.keys()\
                else APIHelper.SKIP
        waitlist_entry_id =\
            dictionary.get("WaitlistEntryId")\
            if dictionary.get("WaitlistEntryId")\
                else APIHelper.SKIP
        client_service_id =\
            dictionary.get("ClientServiceId")\
            if dictionary.get("ClientServiceId")\
                else APIHelper.SKIP
        cross_regional_booking =\
            dictionary.get("CrossRegionalBooking")\
            if "CrossRegionalBooking" in dictionary.keys()\
                else APIHelper.SKIP
        cross_regional_booking_client_service_site_id =\
            dictionary.get("CrossRegionalBookingClientServiceSiteId")\
            if dictionary.get("CrossRegionalBookingClientServiceSiteId")\
                else APIHelper.SKIP
        unique_id =\
            dictionary.get("UniqueId")\
            if dictionary.get("UniqueId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   class_id,
                   test,
                   require_payment,
                   waitlist,
                   send_email,
                   waitlist_entry_id,
                   client_service_id,
                   cross_regional_booking,
                   cross_regional_booking_client_service_site_id,
                   unique_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _class_id=self.class_id
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _require_payment=(
            self.require_payment
            if hasattr(self, "require_payment")
            else None
        )
        _waitlist=(
            self.waitlist
            if hasattr(self, "waitlist")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _waitlist_entry_id=(
            self.waitlist_entry_id
            if hasattr(self, "waitlist_entry_id")
            else None
        )
        _client_service_id=(
            self.client_service_id
            if hasattr(self, "client_service_id")
            else None
        )
        _cross_regional_booking=(
            self.cross_regional_booking
            if hasattr(self, "cross_regional_booking")
            else None
        )
        _cross_regional_booking_client_service_site_id=(
            self.cross_regional_booking_client_service_site_id
            if hasattr(self, "cross_regional_booking_client_service_site_id")
            else None
        )
        _unique_id=(
            self.unique_id
            if hasattr(self, "unique_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"class_id={_class_id!r}, "
            f"test={_test!r}, "
            f"require_payment={_require_payment!r}, "
            f"waitlist={_waitlist!r}, "
            f"send_email={_send_email!r}, "
            f"waitlist_entry_id={_waitlist_entry_id!r}, "
            f"client_service_id={_client_service_id!r}, "
            f"cross_regional_booking={_cross_regional_booking!r}, "
            f"cross_regional_booking_client_service_site_id={_cross_regional_booking_client_service_site_id!r}, "
            f"unique_id={_unique_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _class_id=self.class_id
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _require_payment=(
            self.require_payment
            if hasattr(self, "require_payment")
            else None
        )
        _waitlist=(
            self.waitlist
            if hasattr(self, "waitlist")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _waitlist_entry_id=(
            self.waitlist_entry_id
            if hasattr(self, "waitlist_entry_id")
            else None
        )
        _client_service_id=(
            self.client_service_id
            if hasattr(self, "client_service_id")
            else None
        )
        _cross_regional_booking=(
            self.cross_regional_booking
            if hasattr(self, "cross_regional_booking")
            else None
        )
        _cross_regional_booking_client_service_site_id=(
            self.cross_regional_booking_client_service_site_id
            if hasattr(self, "cross_regional_booking_client_service_site_id")
            else None
        )
        _unique_id=(
            self.unique_id
            if hasattr(self, "unique_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"class_id={_class_id!s}, "
            f"test={_test!s}, "
            f"require_payment={_require_payment!s}, "
            f"waitlist={_waitlist!s}, "
            f"send_email={_send_email!s}, "
            f"waitlist_entry_id={_waitlist_entry_id!s}, "
            f"client_service_id={_client_service_id!s}, "
            f"cross_regional_booking={_cross_regional_booking!s}, "
            f"cross_regional_booking_client_service_site_id={_cross_regional_booking_client_service_site_id!s}, "
            f"unique_id={_unique_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetTipsRequest(object):
    """Implementation of the 'GetTipsRequest' model.

    Attributes:
        staff_id (int): A list of staff IDs that you want to retrieve payroll
            information for. If you do not supply a `StaffId`, all active staff
            members return, ordered by staff ID.
        start_date_time (datetime): The beginning of the date range for the payroll
            information to be returned. The maximum allowed date range is 14 days.  *
            If you do not supply a `StartDateTime`, data returns for the seven days
            prior to the `EndDateTime` that you supply.  * If you do not supply
            either a `StartDateTime` or an `EndDateTime`, the data returns for seven
            days prior to today’s date.
        end_date_time (datetime): The end of the date range for the payroll
            information to be returned. The maximum allowed date range is 14 days.<br
            />  Default: **Today’s date**  * If you do not supply an `EndDateTime`,
            the data returns for the period from the `StartDateTime` that you supply
            to today’s date.  * If you do not supply an `EndDateTime` or a
            `StartDateTime`, data returns for the seven days prior to today’s date.
        location_id (int): A LocationId that you want to retrieve payroll information
            for. If you do not supply a `LocationId`, data from all locations is
            returned.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "location_id": "LocationId",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "staff_id",
        "start_date_time",
        "end_date_time",
        "location_id",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        staff_id=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetTipsRequest instance."""
        # Initialize members of the class
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id,
                   start_date_time,
                   end_date_time,
                   location_id,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"location_id={_location_id!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"location_id={_location_id!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.product import (
    Product,
)
from mindbodypublicapi.models.service import (
    Service,
)


class Package(object):
    """Implementation of the 'Package' model.

    Attributes:
        id (int): The ID of the package.
        name (str): The name of the package.
        discount_percentage (float): The discount percentage applied to the package.
        sell_online (bool): When `true`, only products that can be sold online are
            returned.<br />  When `false`, all products are returned.
        services (List[Service]): Information about the services in the packages.
        products (List[Product]): Information about the products in the packages.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "name": "Name",
        "discount_percentage": "DiscountPercentage",
        "sell_online": "SellOnline",
        "services": "Services",
        "products": "Products",
    }

    _optionals = [
        "id",
        "name",
        "discount_percentage",
        "sell_online",
        "services",
        "products",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        discount_percentage=APIHelper.SKIP,
        sell_online=APIHelper.SKIP,
        services=APIHelper.SKIP,
        products=APIHelper.SKIP):
        """Initialize a Package instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if discount_percentage is not APIHelper.SKIP:
            self.discount_percentage = discount_percentage
        if sell_online is not APIHelper.SKIP:
            self.sell_online = sell_online
        if services is not APIHelper.SKIP:
            self.services = services
        if products is not APIHelper.SKIP:
            self.products = products

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        discount_percentage =\
            dictionary.get("DiscountPercentage")\
            if dictionary.get("DiscountPercentage")\
                else APIHelper.SKIP
        sell_online =\
            dictionary.get("SellOnline")\
            if "SellOnline" in dictionary.keys()\
                else APIHelper.SKIP
        services = None
        if dictionary.get("Services") is not None:
            services = [
                Service.from_dictionary(x)
                    for x in dictionary.get("Services")
            ]
        else:
            services = APIHelper.SKIP
        products = None
        if dictionary.get("Products") is not None:
            products = [
                Product.from_dictionary(x)
                    for x in dictionary.get("Products")
            ]
        else:
            products = APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   name,
                   discount_percentage,
                   sell_online,
                   services,
                   products)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _discount_percentage=(
            self.discount_percentage
            if hasattr(self, "discount_percentage")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _services=(
            self.services
            if hasattr(self, "services")
            else None
        )
        _products=(
            self.products
            if hasattr(self, "products")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"discount_percentage={_discount_percentage!r}, "
            f"sell_online={_sell_online!r}, "
            f"services={_services!r}, "
            f"products={_products!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _discount_percentage=(
            self.discount_percentage
            if hasattr(self, "discount_percentage")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _services=(
            self.services
            if hasattr(self, "services")
            else None
        )
        _products=(
            self.products
            if hasattr(self, "products")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"discount_percentage={_discount_percentage!s}, "
            f"sell_online={_sell_online!s}, "
            f"services={_services!s}, "
            f"products={_products!s}, "
            f")"
        )
